pub struct BigTableClientImpl { /* private fields */ }Expand description
Wrapper for the BigTable connection
Implementations
Sourceimpl BigTableClientImpl
Connect to a BigTable storage model.
impl BigTableClientImpl
Connect to a BigTable storage model.
BigTable is available via the Google Console, and is a schema less storage system.
The db_dsn string should be in the form of
grpc://{BigTableEndpoint}
The settings contains the table_name which is the GRPC path to the data.
(e.g. projects/{project_id}/instances/{instance_id}/tables/{table_id})
where:
BigTableEndpoint is the endpoint domain to use (the default is bigtable.googleapis.com) See
BigTable Endpoints for more details.
project-id is the Google project identifier (see the Google developer console (e.g. ‘autopush-dev’))
instance-id is the Google project instance, (see the Google developer console (e.g. ‘development-1’))
table_id is the Table Name (e.g. ‘autopush’)
This will automatically bring in the default credentials specified by the GOOGLE_APPLICATION_CREDENTIALS
environment variable.
NOTE: Some configurations may look for the default credential file (pointed to by
GOOGLE_APPLICATION_CREDENTIALS) to be stored in
$HOME/.config/gcloud/application_default_credentials.json)
pub fn new(metrics: Arc<StatsdClient>, settings: &DbSettings) -> DbResult<Self>
Sourcepub fn spawn_sweeper(&self, interval: Duration)
pub fn spawn_sweeper(&self, interval: Duration)
Spawn a task to periodically evict idle connections