BigTableDbSettings

Struct BigTableDbSettings 

pub struct BigTableDbSettings {
Show 17 fields pub table_name: String, pub app_profile_id: String, pub router_family: String, pub message_family: String, pub message_topic_family: String, pub database_pool_max_size: Option<u32>, pub grpc_channel_count: Option<u32>, pub database_pool_create_timeout: Option<Duration>, pub database_pool_wait_timeout: Option<Duration>, pub grpc_connect_timeout: Duration, pub grpc_point_attempt_timeout: Duration, pub grpc_scan_attempt_timeout: Duration, pub grpc_point_total_timeout: Duration, pub grpc_scan_total_timeout: Duration, pub route_to_leader: bool, pub retry_count: usize, pub max_router_ttl: Option<Duration>,
}
The settings for accessing the BigTable contents.

Fields

table_name: String

The Table name matches the GRPC template for table paths. e.g. projects/{projectid}/instances/{instanceid}/tables/{tablename} NOTE There is no leading / By default, this (may?) use the * variant which translates to projects/*/instances/*/tables/* which searches all data stored in bigtable.

app_profile_id: String

Routing replication profile id. Should be used everywhere we set table_name when creating requests

router_family: Stringmessage_family: Stringmessage_topic_family: Stringdatabase_pool_max_size: Option<u32>grpc_channel_count: Option<u32>

Number of shared tonic channels used for Bigtable RPCs. Defaults to four. Size it from peak concurrent operations for this workload on one pod, rather than from the maximum logical operation-pool size. See DEFAULT_GRPC_CHANNEL_COUNT for the arithmetic and its caveats.

database_pool_create_timeout: Option<Duration>

Max time (in seconds) to create a pooled client handle.

database_pool_wait_timeout: Option<Duration>

Max time (in seconds) to wait for a logical operation slot.

grpc_connect_timeout: Duration

Max time (in seconds) for DNS, TCP, and TLS connection establishment.

grpc_point_attempt_timeout: Duration

Per-attempt deadline (in seconds) for point reads and writes.

grpc_scan_attempt_timeout: Duration

Per-attempt deadline (in seconds) for message range scans.

grpc_point_total_timeout: Duration

End-to-end retry budget (in seconds) for point reads and writes.

grpc_scan_total_timeout: Duration

End-to-end retry budget (in seconds) for message range scans.

route_to_leader: bool

Include route to leader header in metadata

retry_count: usize

Number of retries after the initial gRPC data operation. Defaults to two. Health checks use this same configured value.

max_router_ttl: Option<Duration>

Max lifetime (in seconds) for a router entry

Implementations